## Overview

hold-this is your everyday helper.

## Installation (pip - auto)
```console
$ pip install hold-this
```

## Installation (pip - manual)
```console
## clone the repository
$ git clone https://github.com/d33pster/hold-this.git

## move into the directory
$ cd hold-this

## install using pip
$ pip install .
```

## usage

```console
$ hold -h
help:
    ? help for <hold>

        - ?help? -

    |    -h or --help
    |         => show this help text.
    |
    |    -g or --github
    |         => git clone repository
    |         format: <username>/repository> or link
END
```